# bamboo

`bamboo` is a python package for processing and analyzing gigapixel imaging data.

## Installation

`bamboo` can be installed using `pip`

```bash
pip install bamboo
```

Or, added to your project using `uv`

```bash
uv add bamboo
```

## License

`bamboo` is licensed under the GNU GPLv3 License (see LICENSE).

You may not use this file except in compliance with the license. A copy of the license has been included in the root of the repository. Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work by you, as defined in the GNU GPLv3 license, shall be licensed as above, without any additional terms or conditions.
